package internal

import (
	"encoding/json"
	"fmt"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"github.com/wechatpay-apiv3/wechatpay-go/core"
	"github.com/wechatpay-apiv3/wechatpay-go/services/cashcoupons"
	"go/types"
	"plugins/utils/wechat"
	"plugins/wechat_cpn/internal/vo"
)

func transConfig(config []byte) (*wechat.Server, error) {
	var c wechat.Server
	err := json.Unmarshal(config, &c)
	if err != nil {
		return nil, err
	}
	return &c, nil
}

func orderReq(order *proto.OrderRequest_Order, product *proto.OrderRequest_Product) (cashcoupons.SendCouponRequest, error) {
	type Extra struct {
		Appid             string `json:"app_id"`
		StockCreatorMchId string `json:"stock_creator_mchid"`
	}
	var extra Extra
	if order.Extra != nil {
		err := json.Unmarshal(order.Extra, &extra)
		if err != nil {
			return cashcoupons.SendCouponRequest{}, fmt.Errorf("order extra json unmarshal error: %v", err)
		}
	}
	return cashcoupons.SendCouponRequest{
		Openid:            core.String(order.Account),
		StockId:           core.String(product.ProductNo),
		OutRequestNo:      core.String(order.OrderNo),
		Appid:             core.String(extra.Appid),
		StockCreatorMchid: core.String(extra.StockCreatorMchId),
	}, nil
}

func orderResp(order *proto.OrderRequest_Order, tradeNo string) *proto.OrderResponse {
	return &proto.OrderResponse{
		Result: &proto.Result{
			Status:  proto.Status_ING,
			OrderNo: order.GetOrderNo(),
			TradeNo: tradeNo,
			Message: "成功",
			Data:    nil,
			Extra:   nil,
		},
	}
}

func queryReq(order *proto.QueryRequest_Order) (*cashcoupons.QueryCouponRequest, error) {
	type Extra struct {
		Appid string `json:"app_id"`
	}
	var extra Extra
	if order.Extra != nil {
		err := json.Unmarshal(order.Extra, &extra)
		if err != nil {
			return nil, fmt.Errorf("order extra json unmarshal error: %v", err)
		}
	}
	return &cashcoupons.QueryCouponRequest{
		CouponId: core.String(order.TradeNo),
		Appid:    core.String(extra.Appid),
		Openid:   core.String(order.Account),
	}, nil
}

func queryResp(request *proto.QueryRequest, resp *cashcoupons.Coupon) *proto.QueryResponse {
	data, _ := resp.MarshalJSON()
	status := vo.QueryStatus(*resp.Status)
	return &proto.QueryResponse{
		Result: &proto.Result{
			Status:  status.GetOrderStatus(),
			OrderNo: request.Order.GetOrderNo(),
			TradeNo: request.Order.TradeNo,
			Message: status.GetText(),
			Data:    data,
			Extra:   nil,
		},
	}
}

func notifyReq(in *proto.NotifyRequest) *types.Nil {
	return nil
}

func notifyResp() *proto.NotifyResponse {
	return &proto.NotifyResponse{
		Result: &proto.Result{
			Status: proto.Status_ING,
			Extra:  nil,
		},
	}
}
